@@ -25,6 +25,7 @@
     THIS MODULE DOES NOT HAVE STABLE PUBLIC API
 """
 
+from argparse import SUPPRESS
 from gettext import gettext as _
 from logging import getLogger
 import argparse
@@ -43,23 +44,23 @@ class CliCommand(PlainBoxCommand, CheckBoxCommandMixIn):
     """
     gettext_domain = "checkbox-ng"
 
-    def __init__(self, provider_loader, config, settings):
+    def __init__(self, provider_loader, config_loader, settings):
         self.provider_loader = provider_loader
-        self.config = config
+        self.config_loader = config_loader
         self.settings = settings
 
     def invoked(self, ns):
         # Run check-config, if requested
         if ns.check_config:
-            retval = CheckConfigInvocation(self.config).run()
+            retval = CheckConfigInvocation(self.config_loader).run()
             return retval
         if ns.new_ui:
             from checkbox_ng.commands.newcli import CliInvocation2
-            return CliInvocation2(self.provider_loader, self.config, ns,
+            return CliInvocation2(self.provider_loader, self.loader_config, ns,
                                   self.settings).run()
         else:
             from checkbox_ng.commands.oldcli import CliInvocation
-            return CliInvocation(self.provider_loader, self.config,
+            return CliInvocation(self.provider_loader, self.loader_config,
                                  self.settings, ns).run()
 
     def register_parser(self, subparsers):
@@ -76,10 +77,14 @@ class CliCommand(PlainBoxCommand, CheckBoxCommandMixIn):
             "--check-config",
             action="store_true",
             help=_("run check-config"))
-        parser.add_argument(
+        group = parser.add_argument_group(title=_("user interface options"))
+        parser.set_defaults(color=None)
+        group.add_argument(
+            '--no-color', dest='color', action='store_false', help=SUPPRESS)
+        group.add_argument(
             '--non-interactive', action='store_true',
             help=_("skip tests that require interactivity"))
-        parser.add_argument(
+        group.add_argument(
             '--dont-suppress-output', action="store_true", default=False,
             help=_("don't suppress the output of certain job plugin types"))
         # Call enhance_parser from CheckBoxCommandMixIn
